@@ -56,7 +56,7 @@ private Q_SLOTS:
 public Q_SLOTS:
     void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
     void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar* cal) Q_DECL_OVERRIDE;
     void handleCollectionsAdded(const Akonadi::Collection::List &collectionList);
 
 private:
